/**
 * NOTE: THIS IS A GENERATED FILE. PLEASE CONSULT THE ORIGINAL IDL FILE
 * FOR THE FULL DOCUMENTION AND LICENSE.
 *
 * @see <a href="http://lxr.mozilla.org/mozilla/search?string=interface+nsIProfileMigrator">
 **/

package org.mozilla.xpcom;

public interface nsIProfileMigrator extends nsISupports
{
  public static final String NS_IPROFILEMIGRATOR_IID =
    "{24ce8b9d-b7ff-4279-aef4-26e158f03e34}";

  public void import_();

  public void migrate(nsIProfileStartup arg1);

}
